@@ -305,8 +305,7 @@ class AnnexKeyParser(object):
         try:
             key = self.format_fn(self.format_string, row)
         except KeyError as exc:
-            ce = CapturedException(exc)
-            lgr.debug("Row missing fields for --key: %s", ce)
+            lgr.warning("Row missing fields for --key: %s", exc)
             return {}
 
         if key == self.empty:
@@ -779,8 +778,13 @@ def extract(rows, colidx_to_name=None,
     info_fns = []
     if formats_meta:
         def set_meta_args(info, row):
-            info["meta_args"] = clean_meta_args(fmt(row)
-                                                for fmt in formats_meta)
+            formatted = []
+            for fmt in formats_meta:
+                try:
+                    formatted.append(fmt(row))
+                except KeyError as exc:
+                    lgr.warning("Row is missing a key to add a metadata field: %s", exc)
+            info["meta_args"] = clean_meta_args(formatted)
         info_fns.append(set_meta_args)
     if key:
         key_parser = AnnexKeyParser(fmt.format, key)
